@@ -110,6 +110,14 @@ const routes = [
       allowedRoles: ['SuperAdmins']
     }
   },
+  {
+    path: '/alarms',
+    name: 'Alarms',
+    component: () => import('../views/alarms/Alarms.vue'),
+    meta: {
+      requiresAuth: true
+    }
+  },
   {
     path: '/logs/audit_trail',
     name: 'AuditTrail',
