@@ -1,11 +1,16 @@
 """A client for Modoboa's public API."""
 
+import logging
 import os
 
 import pkg_resources
 import requests
 from requests.exceptions import RequestException
 
+from django.utils.translation import ugettext as _
+
+logger = logging.getLogger("modoboa.admin")
+
 
 class ModoAPIClient(object):
 
@@ -26,7 +31,10 @@ class ModoAPIClient(object):
             params = {}
         try:
             resp = requests.get(url, params=params)
-        except RequestException:
+        except RequestException as err:
+            logger.critical(
+                _("Failed to communicate with public API: %s"), str(err)
+            )
             return None
         if resp.status_code != 200:
             return None
@@ -36,8 +44,11 @@ class ModoAPIClient(object):
     def local_core_version(self):
         """Return the version installed locally."""
         if self._local_core_version is None:
-            self._local_core_version = pkg_resources.get_distribution(
-                "modoboa").version
+            try:
+                self._local_core_version = pkg_resources.get_distribution(
+                    "modoboa").version
+            except pkg_resources.DistributionNotFound:
+                self._local_core_version = "unknown"
         return self._local_core_version
 
     def list_extensions(self):
@@ -54,7 +65,13 @@ class ModoAPIClient(object):
             url = "{}instances/".format(self._api_url)
             data = {
                 "hostname": hostname, "known_version": self.local_core_version}
-            response = requests.post(url, data=data)
+            try:
+                response = requests.post(url, data=data)
+            except RequestException as err:
+                logger.critical(
+                    _("Failed to communicate with public API: %s"), str(err)
+                )
+                return None
             if response.status_code != 201:
                 return None
             instance = response.json()
@@ -63,8 +80,17 @@ class ModoAPIClient(object):
     def update_instance(self, pk, data):
         """Update instance and send stats."""
         url = "{}instances/{}/".format(self._api_url, pk)
-        response = requests.put(url, data=data)
-        response.raise_for_status()
+        try:
+            response = requests.put(url, data=data)
+        except RequestException as err:
+            logger.critical(
+                _("Failed to communicate with public API: %s"), str(err)
+            )
+            return
+        if response.status_code != 200:
+            logger.critical(
+                _("Failed to communicate with public API: %s"), response.text
+            )
 
     def versions(self):
         """Fetch core and extension versions."""
